@@ -49,17 +49,10 @@
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_FOLDERS_FIRST_WIDGET "sort_folders_first_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_LIST_VIEW_USE_TREE_WIDGET "use_tree_view_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TRASH_CONFIRM_WIDGET "trash_confirm_checkbutton"
-#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_SHOW_HIDDEN_WIDGET "hidden_files_checkbutton"
 
 /* int enums */
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_THUMBNAIL_LIMIT_WIDGET "preview_image_size_combobox"
 
-static const char * const default_view_values[] = {
-	"icon-view",
-	"list-view",
-	NULL
-};
-
 static const char * const sort_order_values[] = {
 	"name",
 	"size",
@@ -580,9 +573,6 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 	GtkWidget *dialog;
 
 	/* setup UI */
-	nautilus_file_management_properties_size_group_create (builder,
-							       "views_label",
-							       2);
 	nautilus_file_management_properties_size_group_create (builder,
 							       "captions_label",
 							       3);
@@ -601,17 +591,10 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 	bind_builder_bool (builder, nautilus_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TRASH_CONFIRM_WIDGET,
 			   NAUTILUS_PREFERENCES_CONFIRM_TRASH);
-	bind_builder_bool (builder, gtk_filechooser_preferences,
-			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_SHOW_HIDDEN_WIDGET,
-			   NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES);
 	bind_builder_bool (builder, nautilus_list_view_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_LIST_VIEW_USE_TREE_WIDGET,
 			   NAUTILUS_PREFERENCES_LIST_VIEW_USE_TREE);
 
-	bind_builder_enum (builder, nautilus_preferences,
-			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_DEFAULT_VIEW_WIDGET,
-			   NAUTILUS_PREFERENCES_DEFAULT_FOLDER_VIEWER,
-			   (const char **) default_view_values);
 	bind_builder_enum (builder, nautilus_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_SORT_ORDER_WIDGET,
 			   NAUTILUS_PREFERENCES_DEFAULT_SORT_ORDER,
